'''
Extensions to the extra_data package. 

contributions should comply with pep8 code structure guidelines.
'''

import os
import logging

import extra_data as ed
from extra_data.read_machinery import find_proposal

from ..util.exceptions import ToolBoxPathError

log = logging.getLogger(__name__)

def find_run_dir(proposal, run):
    """
    Get run directory for given run.

    This method is an extension to 'find_proposal' in the extra_data 
    package and should eventually be transferred to the latter.

    Parameters
    ----------
    proposal: str, int
        Proposal number
    run: str, int
        Run number

    Returns
    -------
    rdir : str
        Run directory as a string

    Raises
    ------
    ToolBoxPathError: Exception
        Error raised if the constructed path does not exist. This may
        happen when entering a non-valid run number, or the folder has
        been renamed/removed.
        
    Comment
    -------
    The rather unspecified Exeption raised, when entering a invalid proposal 
    number stems from the ed package -> to be fixed externally.

    """
    rdir = None

    try:
        pdir = find_proposal(f'p{proposal:06d}')
        rdir = os.path.join(pdir, f'raw/r{run:04d}')
        if os.path.isdir(rdir) is False:
            log.warning("Invalid directory: raise ToolBoxPathError.")
            msg = 'The constructed path does not exist.'
            raise ToolBoxPathError(msg, rdir)

    except ToolBoxPathError:
        raise
    except Exception as err:
        log.error("Unexpected error:", exc_info=True)
        raise

    return rdir